<?php
/**
 * Product Review Groups List Page
 *
 * @package ProductReviewPlugin
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

global $wpdb, $product_review_plugin;
$group_table = $wpdb->prefix . 'product_review_groups';
$review_table = $wpdb->prefix . 'product_reviews';

// Check if tables exist
$group_table_exists = $wpdb->get_var( $wpdb->prepare( "SHOW TABLES LIKE %s", $group_table ) ) === $group_table;
$review_table_exists = $wpdb->get_var( $wpdb->prepare( "SHOW TABLES LIKE %s", $review_table ) ) === $review_table;

if ( ! $group_table_exists || ! $review_table_exists ) {
    echo '<div class="error"><p>' . esc_html__( 'Product Review Plugin tables do not exist. Please deactivate and reactivate the plugin, or use the manual table creation option.', 'product-review-plugin' ) . '</p></div>';
    ?>
    <form method="post" action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>">
        <input type="hidden" name="action" value="manual_table_creation">
        <?php wp_nonce_field( 'manual_table_creation', 'manual_table_creation_nonce' ); ?>
        <input type="submit" class="button button-primary" value="<?php esc_attr_e( 'Attempt Manual Table Creation', 'product-review-plugin' ); ?>">
    </form>
    <?php
    return;
}

// Handle bulk actions
if ( isset( $_POST['action'] ) && $_POST['action'] !== '-1' && check_admin_referer( 'bulk-product-review-groups' ) ) {
    $action = sanitize_key( $_POST['action'] );
    $group_ids = isset( $_POST['group_ids'] ) ? array_map( 'intval', $_POST['group_ids'] ) : array();
    
    if ( ! empty( $group_ids ) ) {
        switch ( $action ) {
            case 'delete':
                foreach ( $group_ids as $id ) {
                    $wpdb->delete( $group_table, array( 'id' => $id ), array( '%d' ) );
                }
                add_settings_error( 'product_review_groups', 'groups_deleted', __( 'Selected groups deleted successfully.', 'product-review-plugin' ), 'updated' );
                break;
            case 'duplicate':
                foreach ( $group_ids as $id ) {
                    $product_review_plugin->duplicate_group( $id );
                }
                add_settings_error( 'product_review_groups', 'groups_duplicated', __( 'Selected groups duplicated successfully.', 'product-review-plugin' ), 'updated' );
                break;
        }
    }
}

// Fetch product review groups
$groups = $wpdb->get_results(
    "SELECT g.*, COALESCE(COUNT(r.id), 0) as review_count 
    FROM $group_table g 
    LEFT JOIN $review_table r ON g.id = r.group_id 
    GROUP BY g.id 
    ORDER BY g.id DESC"
);

if ( $wpdb->last_error ) {
    echo '<div class="error"><p>' . esc_html( sprintf( __( 'Error fetching product review groups: %s', 'product-review-plugin' ), $wpdb->last_error ) ) . '</p></div>';
    return;
}

?>

<div class="wrap">
    <h1 class="wp-heading-inline"><?php esc_html_e( 'Product Review Groups', 'product-review-plugin' ); ?></h1>
    <a href="<?php echo esc_url( admin_url( 'admin.php?page=add-product-review-group' ) ); ?>" class="page-title-action"><?php esc_html_e( 'Add New Group', 'product-review-plugin' ); ?></a>
    <a href="<?php echo esc_url( wp_nonce_url( admin_url( 'admin-post.php?action=export_product_review_groups' ), 'export_product_review_groups' ) ); ?>" class="page-title-action"><?php esc_html_e( 'Export Groups', 'product-review-plugin' ); ?></a>
    <button type="button" class="page-title-action" id="import-groups-button"><?php esc_html_e( 'Import Groups', 'product-review-plugin' ); ?></button>

<form id="import-form" method="post" enctype="multipart/form-data" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>">
    <input type="hidden" name="action" value="import_product_review_groups">
    <?php wp_nonce_field( 'import_product_review_groups' ); ?>
    <input type="file" name="import_file" id="import-file" accept=".json">
</form>

<script type="text/javascript">
    jQuery(document).ready(function($) {
        console.log('Script loaded');  // Debug log
        
        $('#import-groups-button').on('click', function(e) {
            console.log('Import button clicked');  // Debug log
            e.preventDefault();
            $('#import-file').click();
        });

        $('#import-file').on('change', function() {
            console.log('File selected');  // Debug log
            if (this.files.length > 0) {
                if (confirm('<?php echo esc_js( __( 'Are you sure you want to import these groups? This action cannot be undone.', 'product-review-plugin' ) ); ?>')) {
                    console.log('Form submitting');  // Debug log
                    $('#import-form').submit();
                }
            }
        });
    });
</script>

    <?php settings_errors( 'product_review_groups' ); ?>

    <?php if ( empty( $groups ) ) : ?>
        <p><?php esc_html_e( 'No product review groups found. Start by adding a new group!', 'product-review-plugin' ); ?></p>
    <?php else : ?>
        <form method="post">
            <?php wp_nonce_field( 'bulk-product-review-groups' ); ?>
            <div class="tablenav top">
                <div class="alignleft actions bulkactions">
                    <select name="action">
                        <option value="-1"><?php esc_html_e( 'Bulk Actions', 'product-review-plugin' ); ?></option>
                        <option value="delete"><?php esc_html_e( 'Delete', 'product-review-plugin' ); ?></option>
                        <option value="duplicate"><?php esc_html_e( 'Duplicate', 'product-review-plugin' ); ?></option>
                    </select>
                    <input type="submit" class="button action" value="<?php esc_attr_e( 'Apply', 'product-review-plugin' ); ?>">
                </div>
            </div>

            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <td id="cb" class="manage-column column-cb check-column">
                            <input id="cb-select-all-1" type="checkbox">
                        </td>
                        <th><?php esc_html_e( 'ID', 'product-review-plugin' ); ?></th>
                        <th><?php esc_html_e( 'Group Label', 'product-review-plugin' ); ?></th>
                        <th><?php esc_html_e( 'Number of Reviews', 'product-review-plugin' ); ?></th>
                        <th><?php esc_html_e( 'Created At', 'product-review-plugin' ); ?></th>
                        <th><?php esc_html_e( 'Shortcode', 'product-review-plugin' ); ?></th>
                        <th><?php esc_html_e( 'Actions', 'product-review-plugin' ); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ( $groups as $group ) : ?>
                    <tr>
                        <th scope="row" class="check-column">
                            <input type="checkbox" name="group_ids[]" value="<?php echo esc_attr( $group->id ); ?>">
                        </th>
                        <td><?php echo esc_html( $group->id ); ?></td>
                        <td><?php echo esc_html( $group->group_label ); ?></td>
                        <td><?php echo esc_html( $group->review_count ); ?></td>
                        <td><?php echo esc_html( $group->created_at ); ?></td>
                        <td><code>[product_review_group id="<?php echo esc_attr( $group->id ); ?>"]</code></td>
                        <td>
                            <a href="<?php echo esc_url( admin_url( 'admin.php?page=edit-product-review-group&id=' . $group->id ) ); ?>"><?php esc_html_e( 'Edit', 'product-review-plugin' ); ?></a> |
                            <a href="<?php echo esc_url( wp_nonce_url( admin_url( 'admin-post.php?action=duplicate_product_review_group&id=' . $group->id ), 'duplicate_product_review_group_' . $group->id ) ); ?>"><?php esc_html_e( 'Duplicate', 'product-review-plugin' ); ?></a> |
                            <a href="<?php echo esc_url( wp_nonce_url( admin_url( 'admin-post.php?action=delete_product_review_group&id=' . $group->id ), 'delete_product_review_group_' . $group->id, 'prp_delete_nonce' ) ); ?>" class="delete-review-group"><?php esc_html_e( 'Delete', 'product-review-plugin' ); ?></a>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </form>
    <?php endif; ?>
</div>

<?php
// Enqueue and localize the admin script
wp_enqueue_script( 'product-review-admin-script', plugin_dir_url( __FILE__ ) . 'assets/js/admin-script.js', array( 'jquery' ), '1.0', true );
wp_localize_script( 'product-review-admin-script', 'productReviewAdmin', array(
    'confirmDelete' => __( 'Are you sure you want to delete this review group? This action cannot be undone.', 'product-review-plugin' ),
    'confirmBulkDelete' => __( 'Are you sure you want to delete the selected groups? This action cannot be undone.', 'product-review-plugin' ),
    'confirmImport' => __( 'Are you sure you want to import these groups? This action cannot be undone.', 'product-review-plugin' ),
) );