<?php
/**
 * Settings Page for Product Review Plugin
 *
 * @package ProductReviewPlugin
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * Render the settings page for Product Review Plugin.
 */
function product_review_render_settings_page() {
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    // Get default settings and merge with saved options
    $default_settings = ProductReviewPlugin::get_default_settings();
    $saved_options = get_option( 'product_review_settings', array() );
    $options = wp_parse_args( $saved_options, $default_settings );

    // Handle form submission
    if ( isset( $_POST['product_review_settings'] ) && check_admin_referer( 'product_review_settings_nonce' ) ) {
        $options = product_review_sanitize_settings( $_POST['product_review_settings'] );
        update_option( 'product_review_settings', $options );
        add_settings_error(
            'product_review_messages',
            'product_review_message',
            __( 'Settings Saved', 'product-review-plugin' ),
            'updated'
        );
    }

    $active_tab = isset( $_GET['tab'] ) ? sanitize_key( $_GET['tab'] ) : 'currency';
    ?>
    <div class="wrap">
        <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <?php settings_errors( 'product_review_messages' ); ?>

        <h2 class="nav-tab-wrapper">
            <?php
            $tabs = array(
                'currency' => __( 'Currency', 'product-review-plugin' ),
                'font_sizes' => __( 'Font Sizes', 'product-review-plugin' ),
                'colors' => __( 'Colors', 'product-review-plugin' ),
                'headings' => __( 'Headings', 'product-review-plugin' )
            );

            foreach ( $tabs as $tab => $name ) {
                $class = ( $tab === $active_tab ) ? ' nav-tab-active' : '';
                printf(
                    '<a href="?page=product-review-settings&tab=%1$s" class="nav-tab%2$s">%3$s</a>',
                    esc_attr( $tab ),
                    esc_attr( $class ),
                    esc_html( $name )
                );
            }
            ?>
        </h2>

        <form action="" method="post" class="product-review-settings-form">
            <?php
            wp_nonce_field( 'product_review_settings_nonce' );
            
            switch ( $active_tab ) {
                case 'currency':
                    product_review_render_currency_settings( $options );
                    break;
                case 'font_sizes':
                    product_review_render_font_size_settings( $options );
                    break;
                case 'colors':
                    product_review_render_color_settings( $options );
                    break;
                case 'headings':
                    product_review_render_heading_settings( $options );
                    break;
            }
            
            submit_button( __( 'Save Settings', 'product-review-plugin' ) );
            ?>
        </form>
    </div>
    <?php
}

/**
 * Render currency settings.
 *
 * @param array $options Current plugin options.
 */
function product_review_render_currency_settings( $options ) {
    ?>
    <table class="form-table" role="presentation">
        <tr>
            <th scope="row">
                <label for="currency"><?php esc_html_e( 'Currency', 'product-review-plugin' ); ?></label>
            </th>
            <td>
                <select name="product_review_settings[currency]" id="currency">
                    <?php
                    $currencies = product_review_get_currency_list();
                    foreach ( $currencies as $code => $name ) {
                        printf(
                            '<option value="%s" %s>%s</option>',
                            esc_attr( $code ),
                            selected( $options['currency'], $code, false ),
                            esc_html( $name )
                        );
                    }
                    ?>
                </select>
                <p class="description">
                    <?php esc_html_e( 'Select the currency for product prices.', 'product-review-plugin' ); ?>
                </p>
            </td>
        </tr>
    </table>
    <?php
}

/**
 * Render font size settings.
 *
 * @param array $options Current plugin options.
 */
function product_review_render_font_size_settings($options) {
    $font_size_fields = array(
        'font_size' => array(
            'label' => __('Base Font Size', 'product-review-plugin'),
            'default' => 16
        ),
        'button_font_size' => array(
            'label' => __('Button Font Size', 'product-review-plugin'),
            'default' => 16
        ),
        'category_label_font_size' => array(
            'label' => __('Category Label Font Size', 'product-review-plugin'),
            'default' => 14
        ),
        'price_font_size' => array(
            'label' => __('Price Font Size', 'product-review-plugin'),
            'default' => 24
        ),
        'product_name_font_size' => array(
            'label' => __('Product Name Font Size', 'product-review-plugin'),
            'default' => 24
        ),
        'rating_font_size' => array(
            'label' => __('Rating Font Size', 'product-review-plugin'),
            'default' => 24
        ),
        'section_title_font_size' => array(
            'label' => __('Section Title Font Size', 'product-review-plugin'),
            'default' => 14
        ),
        'section_content_font_size' => array(
            'label' => __('Section Content Font Size', 'product-review-plugin'),
            'default' => 15
        )
    );
    ?>
    <table class="form-table" role="presentation">
        <?php foreach ($font_size_fields as $key => $field) : ?>
            <tr>
                <th scope="row">
                    <label for="<?php echo esc_attr($key); ?>">
                        <?php echo esc_html($field['label']); ?>
                    </label>
                </th>
                <td>
                    <input type="number"
                           id="<?php echo esc_attr($key); ?>"
                           name="product_review_settings[<?php echo esc_attr($key); ?>]"
                           value="<?php echo esc_attr($options[$key] ?? $field['default']); ?>"
                           class="small-text"
                           min="0"
                           step="1"
                           data-default="<?php echo esc_attr($field['default']); ?>"
                    /> px
                    <p class="description">
                        <?php 
                        printf(
                            /* translators: %s: default font size */
                            esc_html__('Default: %s px', 'product-review-plugin'),
                            esc_html($field['default'])
                        );
                        ?>
                    </p>
                </td>
            </tr>
        <?php endforeach; ?>
    </table>
    <?php
}
/**
 * Render color settings.
 *
 * @param array $options Current plugin options.
 */
function product_review_render_color_settings( $options ) {
    $color_fields = array(
        'background_color' => array(
            'label' => __( 'Background Color', 'product-review-plugin' ),
            'default' => '#ffffff'
        ),
        'text_color' => array(
            'label' => __( 'Text Color', 'product-review-plugin' ),
            'default' => '#333333'
        ),
        'button_color' => array(
            'label' => __( 'Button Color', 'product-review-plugin' ),
            'default' => '#3b82f6'
        ),
        'button_text_color' => array(
            'label' => __( 'Button Text Color', 'product-review-plugin' ),
            'default' => '#ffffff'
        ),
        'category_label_bg_color' => array(
            'label' => __( 'Category Label Background', 'product-review-plugin' ),
            'default' => '#e0f2fe'
        ),
        'category_label_text_color' => array(
            'label' => __( 'Category Label Text', 'product-review-plugin' ),
            'default' => '#0369a1'
        ),
        'price_color' => array(
            'label' => __( 'Price Color', 'product-review-plugin' ),
            'default' => '#059669'
        ),
        'pros_icon_color' => array(
            'label' => __( 'Pros Icon Color', 'product-review-plugin' ),
            'default' => '#1fb711'
        ),
        'cons_icon_color' => array(
            'label' => __( 'Cons Icon Color', 'product-review-plugin' ),
            'default' => '#ee6a6a'
        ),
        'feature_name_bg_color' => array(
            'label' => __( 'Feature Name Background', 'product-review-plugin' ),
            'default' => '#f0f0f0'
        ),
        'feature_value_bg_color' => array(
            'label' => __( 'Feature Value Background', 'product-review-plugin' ),
            'default' => '#ffffff'
        ),
        'star_fill_color' => array(
        'label' => __('Star Fill Color', 'product-review-plugin'),
        'default' => '#FF9529'
    ),
    'star_empty_color' => array(
        'label' => __('Star Empty Color', 'product-review-plugin'),
        'default' => '#e5e7eb'
    )
    );
    ?>
    <table class="form-table" role="presentation">
        <?php foreach ( $color_fields as $key => $field ) : ?>
            <tr>
                <th scope="row">
                    <label for="<?php echo esc_attr( $key ); ?>">
                        <?php echo esc_html( $field['label'] ); ?>
                    </label>
                </th>
                <td>
                    <input type="text"
                           id="<?php echo esc_attr( $key ); ?>"
                           name="product_review_settings[<?php echo esc_attr( $key ); ?>]"
                           value="<?php echo esc_attr( isset( $options[$key] ) ? $options[$key] : $field['default'] ); ?>"
                           class="product-review-color-picker"
                           data-default-color="<?php echo esc_attr( $field['default'] ); ?>"
                    />
                    <p class="description">
                        <?php 
                        printf(
                            /* translators: %s: default color value */
                            esc_html__( 'Default: %s', 'product-review-plugin' ),
                            esc_html( $field['default'] )
                        );
                        ?>
                    </p>
                </td>
            </tr>
        <?php endforeach; ?>
    </table>
    <?php
}
/**
 * Render heading settings.
 *
 * @param array $options Current plugin options.
 */
function product_review_render_heading_settings($options) {
    $heading_fields = array(
        'heading_summary' => array(
            'label' => __('Summary Heading', 'product-review-plugin'),
            'default' => __('Summary', 'product-review-plugin')
        ),
        'heading_pros' => array(
            'label' => __('Pros Heading', 'product-review-plugin'),
            'default' => __('Pros', 'product-review-plugin')
        ),
        'heading_cons' => array(
            'label' => __('Cons Heading', 'product-review-plugin'),
            'default' => __('Cons', 'product-review-plugin')
        ),
        'heading_description' => array(
            'label' => __('Description Heading', 'product-review-plugin'),
            'default' => __('Description', 'product-review-plugin')
        ),
        'heading_who_should_buy' => array(
            'label' => __('Who Should Buy Heading', 'product-review-plugin'),
            'default' => __('Who Should Buy It?', 'product-review-plugin')
        )
    );
    ?>
    <table class="form-table" role="presentation">
        <?php foreach ($heading_fields as $key => $field) : ?>
            <tr>
                <th scope="row">
                    <label for="<?php echo esc_attr($key); ?>">
                        <?php echo esc_html($field['label']); ?>
                    </label>
                </th>
                <td>
                    <input type="text"
                           id="<?php echo esc_attr($key); ?>"
                           name="product_review_settings[<?php echo esc_attr($key); ?>]"
                           value="<?php echo esc_attr(isset($options[$key]) ? $options[$key] : $field['default']); ?>"
                           class="regular-text"
                    />
                    <p class="description">
                        <?php 
                        printf(
                            /* translators: %s: default heading text */
                            esc_html__('Default: %s', 'product-review-plugin'),
                            esc_html($field['default'])
                        );
                        ?>
                    </p>
                </td>
            </tr>
        <?php endforeach; ?>
    </table>
    <?php
}
/**
 * Sanitize settings before saving.
 *
 * @param array $input The input array to sanitize.
 * @return array The sanitized input array.
 */
function product_review_sanitize_settings( $input ) {
    $sanitized_input = array();
    $default_settings = ProductReviewPlugin::get_default_settings();
     // Font sizes
    $font_size_keys = array(
        'font_size',
        'button_font_size',
        'category_label_font_size',
        'price_font_size',
        'product_name_font_size',
        'rating_font_size',
        'section_title_font_size',
        'section_content_font_size'
    );

    foreach ($font_size_keys as $key) {
        if (isset($input[$key])) {
            $value = absint($input[$key]);
            $sanitized_input[$key] = $value > 0 ? $value : $default_settings[$key];
        }
    }


    foreach ( $input as $key => $value ) {
        if ( strpos( $key, 'color' ) !== false ) {
            $sanitized_input[$key] = sanitize_hex_color( $value );
        } elseif ( strpos( $key, 'font_size' ) !== false ) {
            $sanitized_input[$key] = absint( $value );
        } elseif ( strpos( $key, 'heading_' ) !== false ) {
            $sanitized_input[$key] = sanitize_text_field( $value );
        } elseif ( $key === 'currency' ) {
            $sanitized_input[$key] = sanitize_text_field( $value );
        } else {
            $sanitized_input[$key] = isset( $default_settings[$key] ) ? sanitize_text_field( $value ) : null;
        }
    }

    return $sanitized_input;
}

/**
 * Get the list of supported currencies.
 *
 * @return array Array of currency codes and names.
 */
function product_review_get_currency_list() {
    return array(
        'BDT' => __( 'Bangladeshi Taka (৳)', 'product-review-plugin' ),
        'BRL' => __( 'Brazilian Real (R$)', 'product-review-plugin' ),
        'CAD' => __( 'Canadian Dollar (C$)', 'product-review-plugin' ),
        'CHF' => __( 'Swiss Franc (CHF)', 'product-review-plugin' ),
        'CNY' => __( 'Chinese Yuan (¥)', 'product-review-plugin' ),
        'EUR' => __( 'Euro (€)', 'product-review-plugin' ),
        'GBP' => __( 'British Pound (£)', 'product-review-plugin' ),
        'HKD' => __( 'Hong Kong Dollar (HK$)', 'product-review-plugin' ),
        'INR' => __( 'Indian Rupee (₹)', 'product-review-plugin' ),
        'JPY' => __( 'Japanese Yen (¥)', 'product-review-plugin' ),
        'KRW' => __( 'South Korean Won (₩)', 'product-review-plugin' ),
        'MXN' => __( 'Mexican Peso (MX$)', 'product-review-plugin' ),
        'NZD' => __( 'New Zealand Dollar (NZ$)', 'product-review-plugin' ),
        'RUB' => __( 'Russian Ruble (₽)', 'product-review-plugin' ),
        'SGD' => __( 'Singapore Dollar (S$)', 'product-review-plugin' ),
        'TRY' => __( 'Turkish Lira (₺)', 'product-review-plugin' ),
        'TWD' => __( 'New Taiwan Dollar (NT$)', 'product-review-plugin' ),
        'USD' => __( 'US Dollar ($)', 'product-review-plugin' ),
        'ZAR' => __( 'South African Rand (R)', 'product-review-plugin' ),
        // Add more currencies as needed
    );
}

/**
 * Enqueue scripts and styles for the settings page.
 *
 * @param string $hook The current admin page.
 */
function product_review_enqueue_admin_scripts( $hook ) {
    if ( 'product-reviews_page_product-review-settings' !== $hook ) {
        return;
    }

    wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_script( 'wp-color-picker' );
    wp_enqueue_script(
        'product-review-settings',
        plugin_dir_url( __FILE__ ) . 'assets/js/settings.js',
        array( 'jquery', 'wp-color-picker' ),
        '1.0',
        true
    );

    wp_localize_script(
        'product-review-settings',
        'productReviewSettings',
        array(
            'resetConfirm' => __( 'Are you sure you want to reset all settings to default values?', 'product-review-plugin' ),
            'resetAllLabel' => __( 'Reset All to Default', 'product-review-plugin' ),
        )
    );
}
add_action( 'admin_enqueue_scripts', 'product_review_enqueue_admin_scripts' );

// Add this new function at the end of your settings.php file
function product_review_add_settings_inline_script() {
    ?>
    <script type="text/javascript">
        jQuery(document).ready(function($) {
            $('.product-review-color-picker').wpColorPicker();

            // Add "Reset All to Default" button
            var $resetAllButton = $('<button type="button" class="button button-secondary">' + 
                productReviewSettings.resetAllLabel + '</button>');
            $('.product-review-settings-form').append($resetAllButton);

            $resetAllButton.on('click', function(e) {
                e.preventDefault();
                if (confirm(productReviewSettings.resetConfirm)) {
                    $('.product-review-color-picker').each(function() {
                        $(this).wpColorPicker('color', $(this).data('default-color'));
                    });
                    // Reset other fields as needed
                    // You may want to add more reset logic here for other field types
                }
            });
        });
    </script>
    <?php
}
add_action( 'admin_footer-product-reviews_page_product-review-settings', 'product_review_add_settings_inline_script' );

// Initialize the settings page
product_review_render_settings_page();