<?php
/**
 * Plugin Name: AJ Product Review
 * Plugin URI: https://teclans.info/store/product/product-review-plugin/
 * Description: A customizable product review plugin with dynamic backend settings, group functionality, and license validation.
 * Version: 1.3
 * Requires at least: 5.8
 * Requires PHP: 7.3
 * Author: MD. Abdullah Al Aslam
 * Author URI: https://teclans.info
 * Text Domain: product-review-shortcode
 * Domain Path: /languages
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 *
 * @package ProductReviewPlugin
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}
// Define plugin constants
define('PRODUCT_REVIEW_VERSION', '1.3');
define('PRODUCT_REVIEW_PLUGIN_FILE', __FILE__);
define('PRODUCT_REVIEW_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('PRODUCT_REVIEW_PLUGIN_URL', plugin_dir_url(__FILE__));

/**
 * Main class for the Product Review Plugin.
 */
class ProductReviewPlugin {
    /**
     * Plugin settings
     *
     * @var array
     */
    private $settings;

    /**
     * Constructor.
     */
    public function __construct() {
        $this->settings = get_option('product_review_settings', array());
        $this->init_hooks();
    }

    /**
     * Initialize WordPress hooks
     */
    private function init_hooks() {
        // Basic plugin setup
        add_action('plugins_loaded', array($this, 'load_plugin_textdomain'));
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_frontend_scripts'), 999);
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
        
        // Shortcodes and content filters
        add_shortcode('product_review_group', array($this, 'product_review_group_shortcode'));
        add_filter('the_content', array($this, 'add_schema_to_content'));
        
        // Admin post handlers
        add_action('admin_post_add_product_review_group', array($this, 'handle_add_product_review_group'));
        add_action('admin_post_edit_product_review_group', array($this, 'handle_edit_product_review_group'));
        add_action('admin_post_delete_product_review_group', array($this, 'handle_delete_product_review_group'));
        add_action('admin_post_export_product_review_groups', array($this, 'handle_export_product_review_groups'));
        add_action('admin_post_import_product_review_groups', array($this, 'handle_import_product_review_groups'));
        add_action('admin_post_duplicate_product_review_group', array($this, 'handle_duplicate_product_review_group'));

        // AJAX handlers
        add_action('wp_ajax_product_review_save_settings', array($this, 'handle_ajax_save_settings'));
        
        // Admin functionality
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_notices', array($this, 'show_upgrade_notice'));
        
        // Cache clearing
        add_action('product_review_group_updated', array($this, 'clear_review_caches_on_update'));
        add_action('product_review_group_deleted', array($this, 'clear_review_cache'));
        add_action('update_option_product_review_settings', array($this, 'clear_options_cache'));
    }

    /**
     * Clear caches
     */
    public function clear_review_caches_on_update($group_id) {
        wp_cache_delete('product_review_group_' . $group_id);
        wp_cache_delete('product_review_schema_' . $group_id);
    }

    public function clear_review_cache($group_id) {
        wp_cache_delete('product_review_group_' . $group_id);
        wp_cache_delete('product_review_schema_' . $group_id);
    }

    public function clear_options_cache() {
        wp_cache_delete('product_review_options');
    }


    /**
     * Load plugin textdomain
     */
    public function load_plugin_textdomain() {
        load_plugin_textdomain('product-review-plugin', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }

    /**
     * Add admin menu items
     */
    public function add_admin_menu() {
        add_menu_page(
            __('Product Reviews', 'product-review-plugin'),
            __('Product Reviews', 'product-review-plugin'),
            'manage_options',
            'product-reviews',
            array($this, 'product_reviews_page'),
            'dashicons-star-filled'
        );

        add_submenu_page(
            'product-reviews',
            __('All Product Review Groups', 'product-review-plugin'),
            __('All Groups', 'product-review-plugin'),
            'manage_options',
            'product-reviews',
            array($this, 'product_reviews_page')
        );

        add_submenu_page(
            'product-reviews',
            __('Add New Product Review Group', 'product-review-plugin'),
            __('Add New Group', 'product-review-plugin'),
            'manage_options',
            'add-product-review-group',
            array($this, 'add_product_review_group_page')
        );

        add_submenu_page(
            null,
            __('Edit Product Review Group', 'product-review-plugin'),
            __('Edit Group', 'product-review-plugin'),
            'manage_options',
            'edit-product-review-group',
            array($this, 'edit_product_review_group_page')
        );

        add_submenu_page(
            'product-reviews',
            __('Settings', 'product-review-plugin'),
            __('Settings', 'product-review-plugin'),
            'manage_options',
            'product-review-settings',
            array($this, 'settings_page')
        );

        add_submenu_page(
            'product-reviews',
            __('License', 'product-review-plugin'),
            __('License', 'product-review-plugin'),
            'manage_options',
            'product-review-license',
            array($this, 'license_page')
        );
    }

    /**
     * Register plugin settings
     */
    public function register_settings() {
        register_setting('product_review_settings', 'product_review_settings', array($this, 'sanitize_settings'));
        register_setting('product_review_license', 'product_review_license_key');
        register_setting('product_review_license', 'product_review_license_status');
    }

    /**
     * Enqueue frontend scripts and styles
     */
    public function enqueue_frontend_scripts() {
    wp_enqueue_style(
        'product-review-style',
        plugin_dir_url(__FILE__) . 'assets/css/frontend-style.css',
        array(),
        PRODUCT_REVIEW_VERSION
    );

    wp_enqueue_script(
        'product-review-script',
        plugin_dir_url(__FILE__) . 'assets/js/frontend-script.js',
        array('jquery'),
        PRODUCT_REVIEW_VERSION,
        true
    );

    // Get settings with defaults
    $default_settings = self::get_default_settings();
    $saved_settings = get_option('product_review_settings', array());
    $options = wp_parse_args($saved_settings, $default_settings);

    // Generate and add custom CSS
    $custom_css = $this->generate_custom_css($options);
    wp_add_inline_style('product-review-style', $custom_css);
}

/**
 * Enqueue admin scripts and styles.
 *
 * @param string $hook Current admin page.
 */
public function enqueue_admin_scripts($hook) {
    // Only load on our plugin pages
    if (!in_array($hook, array(
        'product-reviews_page_product-review-settings',
        'product-reviews_page_add-product-review-group',
        'admin_page_edit-product-review-group'
    ))) {
        return;
    }

    // Enqueue WordPress media uploader
    wp_enqueue_media();

    // Enqueue WordPress color picker
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('wp-color-picker');

    // Enqueue our admin script
    wp_enqueue_script(
        'product-review-admin-script',
        plugin_dir_url(__FILE__) . 'assets/js/admin-script.js',
        array('jquery', 'wp-color-picker', 'media-upload'),
        PRODUCT_REVIEW_VERSION,
        true
    );

    // Localize script
     wp_localize_script(
        'product-review-admin-script',
        'productReviewSettings',
        array(
            'isPremiumUser' => self::is_premium_user(),
            'maxReviews' => self::is_premium_user() ? PHP_INT_MAX : 2,
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('product_review_nonce'),
            'resetConfirm' => __('Are you sure you want to reset all settings to default values?', 'product-review-plugin'),
            'resetAllLabel' => __('Reset All to Default', 'product-review-plugin'),
            'resetToDefaultText' => __('Reset', 'product-review-plugin')
        )
    );

    // Localize text strings
    wp_localize_script('product-review-admin-script', 'productReviewL10n', array(
    'mediaUpload' => array(
        'title' => __('Choose Image', 'product-review-plugin'),
        'button' => __('Use This Image', 'product-review-plugin'),
        'uploadButton' => __('Upload Image', 'product-review-plugin'),
        'removeButton' => __('Remove Image', 'product-review-plugin')
    ),
    'messages' => array(
        'maxReviews' => __('You have reached the maximum number of reviews allowed for free users. Please upgrade to add more.', 'product-review-plugin'),
        'minReview' => __('You must have at least one review.', 'product-review-plugin'),
        'confirmDelete' => __('Are you sure you want to delete this item?', 'product-review-plugin')
    ),
    'labels' => array(
        'reviewNumber' => __('Product Review #', 'product-review-plugin'),
        'remove' => __('Remove', 'product-review-plugin'),
        'duplicate' => __('Duplicate', 'product-review-plugin')
    )
));

    // Enqueue admin styles
    wp_enqueue_style(
        'product-review-admin-style',
        plugin_dir_url(__FILE__) . 'assets/css/admin-style.css',
        array(),
        PRODUCT_REVIEW_VERSION
    );
}

    public function handle_ajax_save_settings() {
        check_ajax_referer('product_review_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized');
        }

        $settings = isset($_POST['settings']) ? $_POST['settings'] : array();
        $sanitized_settings = $this->sanitize_settings($settings);
        
        update_option('product_review_settings', $sanitized_settings);
        $this->clear_options_cache();

        wp_send_json_success(array(
            'message' => __('Settings saved successfully.', 'product-review-plugin')
        ));
    }
/**
     * Sanitize settings
     */
    private function sanitize_settings($settings) {
        $sanitized = array();
        $default_settings = self::get_default_settings();

        foreach ($settings as $key => $value) {
            switch (true) {
                case strpos($key, 'color') !== false:
                    $sanitized[$key] = sanitize_hex_color($value);
                    break;
                case strpos($key, 'font_size') !== false:
                    $sanitized[$key] = absint($value);
                    break;
                case strpos($key, 'heading_') !== false:
                    $sanitized[$key] = sanitize_text_field($value);
                    break;
                case $key === 'currency':
                    $sanitized[$key] = sanitize_text_field($value);
                    break;
                default:
                    if (isset($default_settings[$key])) {
                        $sanitized[$key] = sanitize_text_field($value);
                    }
            }
        }

        return $sanitized;
    }


    /**
     * Product review group shortcode callback
     *
     * @param array $atts Shortcode attributes
     * @return string Shortcode output
     */
    public function product_review_group_shortcode($atts) {
        $atts = shortcode_atts(array(
            'id' => 0,
        ), $atts, 'product_review_group');

        if ($atts['id'] == 0) {
            return esc_html__('Please specify a product review group ID.', 'product-review-plugin');
        }

        require_once plugin_dir_path(__FILE__) . 'frontend-display.php';
        return generate_product_review_group_html($atts['id']);
    }

    /**
     * Add schema markup to content
     *
     * @param string $content The post content
     * @return string Modified content
     */
    public function add_schema_to_content($content) {
        global $post;
        if (has_shortcode($post->post_content, 'product_review_group')) {
            preg_match('/\[product_review_group id="(\d+)"\]/', $post->post_content, $matches);
            if (!empty($matches[1])) {
                $group_id = $matches[1];
                require_once plugin_dir_path(__FILE__) . 'frontend-display.php';
                $schema_markup = generate_product_review_schema($group_id);
                $content = $schema_markup . $content;
            }
        }
        return $content;
    }

    /**
     * Handle adding a product review group
     */
    public function handle_add_product_review_group() {
        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('Unauthorized user', 'product-review-plugin'));
        }

        check_admin_referer('add_product_review_group_nonce');

        global $wpdb;
        $group_table = $wpdb->prefix . 'product_review_groups';
        $review_table = $wpdb->prefix . 'product_reviews';

        $group_label = sanitize_text_field($_POST['group_label']);

        $wpdb->insert($group_table, array('group_label' => $group_label));
        $group_id = $wpdb->insert_id;

        $this->save_review_data($group_id, $_POST);

        // Clear caches after adding
        do_action('product_review_group_updated', $group_id);

        wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=group_added'));
        exit;
    }

    /**
     * Handle editing a product review group
     */
    public function handle_edit_product_review_group() {
        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('Unauthorized user', 'product-review-plugin'));
        }

        check_admin_referer('edit_product_review_group_nonce');

        $group_id = intval($_POST['group_id']);
        
        global $wpdb;
        $group_table = $wpdb->prefix . 'product_review_groups';
        
        $wpdb->update(
            $group_table,
            array('group_label' => sanitize_text_field($_POST['group_label'])),
            array('id' => $group_id)
        );

        $this->save_review_data($group_id, $_POST);

        // Clear caches after update
        do_action('product_review_group_updated', $group_id);

        wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=group_updated'));
        exit;
    }

    /**
     * Save review data helper method
     *
     * @param int   $group_id The group ID
     * @param array $data     The POST data
     */
    private function save_review_data($group_id, $data) {
        global $wpdb;
        $review_table = $wpdb->prefix . 'product_reviews';

        // Delete existing reviews
        $wpdb->delete($review_table, array('group_id' => $group_id));

        // Process and save new reviews
        $product_names = isset($data['product_name']) ? $data['product_name'] : array();
        
        for ($i = 0; $i < count($product_names); $i++) {
            $features = array();
            if (isset($data['feature_name'][$i]) && isset($data['feature_value'][$i])) {
                $feature_names = $data['feature_name'][$i];
                $feature_values = $data['feature_value'][$i];
                for ($j = 0; $j < count($feature_names); $j++) {
                    if (!empty($feature_names[$j]) || !empty($feature_values[$j])) {
                        $features[] = array(
                            'name' => sanitize_text_field($feature_names[$j]),
                            'value' => sanitize_text_field($feature_values[$j])
                        );
                    }
                }
            }

            $review_data = array(
                'group_id' => $group_id,
                'product_name' => sanitize_text_field($data['product_name'][$i]),
                'product_category' => sanitize_text_field($data['product_category'][$i]),
                'product_rating' => floatval($data['product_rating'][$i]),
                'product_price' => floatval($data['product_price'][$i]),
                'product_summary' => sanitize_textarea_field($data['product_summary'][$i]),
                'product_features' => wp_json_encode($features),
                'product_pros' => sanitize_textarea_field($data['product_pros'][$i]),
                'product_cons' => sanitize_textarea_field($data['product_cons'][$i]),
                'product_who_should_buy' => sanitize_textarea_field($data['product_who_should_buy'][$i]),
                'image_url' => esc_url_raw($data['product_image'][$i]),
                'description' => sanitize_textarea_field($data['product_description'][$i]),
                'button_text' => sanitize_text_field($data['button_text'][$i]),
                'button_url' => esc_url_raw($data['button_url'][$i]),);

            $wpdb->insert($review_table, $review_data);
        }
    }

    /**
     * Handle deleting a product review group
     */
    public function handle_delete_product_review_group() {
        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('Unauthorized user', 'product-review-plugin'));
        }

        if (!isset($_GET['id']) || !isset($_GET['prp_delete_nonce'])) {
            wp_die(esc_html__('Invalid request', 'product-review-plugin'));
        }

        $group_id = intval($_GET['id']);
        $nonce = $_GET['prp_delete_nonce'];

        if (!wp_verify_nonce($nonce, 'delete_product_review_group_' . $group_id)) {
            wp_die(esc_html__('Invalid nonce', 'product-review-plugin'));
        }

        global $wpdb;
        $group_table = $wpdb->prefix . 'product_review_groups';
        $review_table = $wpdb->prefix . 'product_reviews';

        // Clear caches before deletion
        do_action('product_review_group_deleted', $group_id);

        // Delete associated reviews first
        $wpdb->delete($review_table, array('group_id' => $group_id));

        // Delete the group
        $wpdb->delete($group_table, array('id' => $group_id));

        wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=group_deleted'));
        exit;
    }

    /**
     * Handle exporting product review groups
     */
    public function handle_export_product_review_groups() {
        check_admin_referer('export_product_review_groups');
        
        global $wpdb;
        $group_table = $wpdb->prefix . 'product_review_groups';
        $review_table = $wpdb->prefix . 'product_reviews';

        $groups = $wpdb->get_results("SELECT * FROM $group_table");
        $export_data = array();

        foreach ($groups as $group) {
            $reviews = $wpdb->get_results($wpdb->prepare(
                "SELECT * FROM $review_table WHERE group_id = %d",
                $group->id
            ));
            
            $export_data[] = array(
                'group' => $group,
                'reviews' => $reviews
            );
        }

        header('Content-Type: application/json');
        header('Content-Disposition: attachment; filename="product_review_groups_export.json"');
        echo wp_json_encode($export_data);
        exit;
    }

    /**
     * Handle importing product review groups
     */
    public function handle_import_product_review_groups() {
        if (!check_admin_referer('import_product_review_groups')) {
            wp_die('Invalid nonce');
        }

        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('Unauthorized user', 'product-review-plugin'));
        }

        if (!isset($_FILES['import_file'])) {
            wp_die(esc_html__('No file uploaded', 'product-review-plugin'));
        }

        $file_content = file_get_contents($_FILES['import_file']['tmp_name']);
        $import_data = json_decode($file_content, true);

        if (!$import_data || !is_array($import_data)) {
            wp_die(esc_html__('Invalid import file or data structure', 'product-review-plugin'));
        }

        global $wpdb;
        $group_table = $wpdb->prefix . 'product_review_groups';
        $review_table = $wpdb->prefix . 'product_reviews';

        foreach ($import_data as $item) {
            if (!isset($item['group']) || !is_array($item['group'])) {
                continue;
            }

            $group = $item['group'];
            unset($group['id']);

            $wpdb->insert($group_table, $group);
            $new_group_id = $wpdb->insert_id;

            if (!isset($item['reviews']) || !is_array($item['reviews'])) {
                continue;
            }

            foreach ($item['reviews'] as $review) {
                unset($review['id']);
                $review['group_id'] = $new_group_id;
                $wpdb->insert($review_table, $review);
            }

            // Clear caches for the new group
            do_action('product_review_group_updated', $new_group_id);
        }

        wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=import_success'));
        exit;
    }

    /**
     * Handle duplicating a product review group
     */
    public function handle_duplicate_product_review_group() {
        $group_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
        check_admin_referer('duplicate_product_review_group_' . $group_id);

        if ($group_id) {
            $new_group_id = $this->duplicate_group($group_id);
            if ($new_group_id) {
                // Clear caches for the new group
                do_action('product_review_group_updated', $new_group_id);
                wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=group_duplicated'));
            } else {
                wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=duplicate_failed'));
            }
        } else {
            wp_safe_redirect(admin_url('admin.php?page=product-reviews&message=duplicate_failed'));
        }
        exit;
    }
    
    /**
     * Display the product reviews page
     */
    public function product_reviews_page() {
        require_once plugin_dir_path(__FILE__) . 'admin/product-review-groups-list.php';
    }

    /**
     * Display the add product review group page
     */
    public function add_product_review_group_page() {
        require_once plugin_dir_path(__FILE__) . 'admin/add-product-review-group.php';
    }

    /**
     * Display the edit product review group page
     */
    public function edit_product_review_group_page() {
        require_once plugin_dir_path(__FILE__) . 'admin/edit-product-review-group.php';
    }

    /**
     * Display the settings page
     */
    public function settings_page() {
        require_once plugin_dir_path(__FILE__) . 'admin/settings-page.php';
    }

    /**
 * Display the license page following WordPress standards
 *
 * @since 1.0.0
 * @return void
 */
public function license_page() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Process form submission
    $this->handle_license_submission();

    // Get current license status
    $license_key = get_option('product_review_license_key', '');
    $license_status = get_option('product_review_license_status', 'inactive');

    // Admin page wrapper
    ?>
    <div class="wrap">
        <h1 class="wp-heading-inline">
            <?php echo esc_html(get_admin_page_title()); ?>
        </h1>
        
        <div class="notice-container">
            <?php settings_errors('product_review_license'); ?>
        </div>

        <div class="card">
            <form method="post" action="">
                <?php wp_nonce_field('product_review_license_nonce'); ?>
                <table class="form-table" role="presentation">
                    <tbody>
                        <tr>
                            <th scope="row">
                                <label for="product_review_license_key">
                                    <?php esc_html_e('License Key', 'product-review-plugin'); ?>
                                </label>
                            </th>
                            <td>
                                <input type="password"
                                       name="product_review_license_key"
                                       id="product_review_license_key"
                                       value="<?php echo esc_attr($license_key); ?>"
                                       class="regular-text"
                                       <?php disabled($license_status === 'active'); ?>
                                />
                                <p class="description">
                                    <?php 
                                    if ($license_status === 'active') {
                                        esc_html_e('Your license is currently active.', 'product-review-plugin');
                                    } else {
                                        esc_html_e('Enter your license key to enable premium features.', 'product-review-plugin');
                                    }
                                    ?>
                                </p>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row">
                                <?php esc_html_e('License Status', 'product-review-plugin'); ?>
                            </th>
                            <td>
                                <?php if ($license_status === 'active'): ?>
                                    <span class="notice notice-success notice-alt inline">
                                        <p><?php esc_html_e('Active', 'product-review-plugin'); ?></p>
                                    </span>
                                <?php else: ?>
                                    <span class="notice notice-warning notice-alt inline">
                                        <p><?php esc_html_e('Inactive', 'product-review-plugin'); ?></p>
                                    </span>
                                <?php endif; ?>
                            </td>
                        </tr>
                    </tbody>
                </table>
                
                <p class="submit">
                    <?php if ($license_status === 'inactive'): ?>
                        <input type="submit"
                               name="product_review_license_activate"
                               class="button button-primary"
                               value="<?php esc_attr_e('Activate License', 'product-review-plugin'); ?>"
                        />
                    <?php else: ?>
                        <input type="submit"
                               name="product_review_license_deactivate"
                               class="button button-secondary"
                               value="<?php esc_attr_e('Deactivate License', 'product-review-plugin'); ?>"
                        />
                    <?php endif; ?>
                </p>
            </form>
        </div>
    </div>
    <?php
}

/**
 * Handle license form submission
 *
 * @since 1.0.0
 * @return void
 */
private function handle_license_submission() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Handle activation
    if (isset($_POST['product_review_license_activate'])) {
        if (!check_admin_referer('product_review_license_nonce')) {
            wp_die(esc_html__('Security check failed', 'product-review-plugin'));
        }

        $license_key = isset($_POST['product_review_license_key']) 
            ? sanitize_text_field(wp_unslash($_POST['product_review_license_key'])) 
            : '';

        if (empty($license_key)) {
            add_settings_error(
                'product_review_license',
                'empty_license',
                __('Please enter a license key.', 'product-review-plugin'),
                'error'
            );
            return;
        }

        // Validate license
        $validation_result = self::validate_license($license_key);

        if ($validation_result['is_valid']) {
            update_option('product_review_license_key', $license_key);
            update_option('product_review_license_status', 'active');
            add_settings_error(
                'product_review_license',
                'license_activated',
                __('License activated successfully.', 'product-review-plugin'),
                'success'
            );
            
            // Clear any cached premium status
            delete_transient('product_review_premium_status');
        } else {
            $error_message = isset($validation_result['error']) 
                ? $validation_result['error'] 
                : __('License activation failed.', 'product-review-plugin');
            
            add_settings_error(
                'product_review_license',
                'license_error',
                esc_html($error_message),
                'error'
            );
        }
    }

    // Handle deactivation
    if (isset($_POST['product_review_license_deactivate'])) {
        if (!check_admin_referer('product_review_license_nonce')) {
            wp_die(esc_html__('Security check failed', 'product-review-plugin'));
        }

        // Clear license data
        delete_option('product_review_license_key');
        update_option('product_review_license_status', 'inactive');
        delete_transient('product_review_premium_status');

        add_settings_error(
            'product_review_license',
            'license_deactivated',
            __('License deactivated successfully.', 'product-review-plugin'),
            'success'
        );
    }
}
    /**
     * Generate custom CSS based on settings
     *
     * @param array $options Plugin settings
     * @return string Generated CSS
     */
public function generate_custom_css($options) {
    $default_settings = self::get_default_settings();
    $options = wp_parse_args($options, $default_settings);

    ob_start();
    ?>
    .product-review-plugin .product-review-container {
        background-color: <?php echo esc_html($options['background_color']); ?>;
        color: <?php echo esc_html($options['text_color']); ?>;
        font-size: <?php echo absint($options['font_size']); ?>px;
    }

    .product-review-plugin .add-to-cart {
        background-color: <?php echo esc_html($options['button_color']); ?>;
        color: <?php echo esc_html($options['button_text_color']); ?>;
        font-size: <?php echo absint($options['button_font_size']); ?>px;
    }

    .product-review-plugin .category-label {
        background-color: <?php echo esc_html($options['category_label_bg_color']); ?>;
        color: <?php echo esc_html($options['category_label_text_color']); ?>;
        font-size: <?php echo absint($options['category_label_font_size']); ?>px;
    }

    .product-review-plugin .price {
        color: <?php echo esc_html($options['price_color']); ?>;
        font-size: <?php echo absint($options['price_font_size'] ?? 24); ?>px;
    }

    .product-review-plugin .product-name {
        font-size: <?php echo absint($options['product_name_font_size'] ?? 24); ?>px;
    }

    .product-review-plugin .rating-value {
        font-size: <?php echo absint($options['rating_font_size'] ?? 24); ?>px;
    }

    .product-review-plugin .section-toggle .section-title {
        font-size: <?php echo absint($options['section_title_font_size'] ?? 14); ?>px;
    }

    .product-review-plugin .section-content,
    .product-review-plugin .features-table,
    .product-review-plugin .review-list {
        font-size: <?php echo absint($options['section_content_font_size'] ?? 15); ?>px;
    }

    .product-review-plugin .star {
        font-size: <?php echo absint($options['rating_font_size'] ?? 18); ?>px;
    }

    .product-review-plugin .icon.pro {
        color: <?php echo esc_html($options['pros_icon_color'] ?? '#1fb711'); ?>;
    }

    .product-review-plugin .icon.con {
        color: <?php echo esc_html($options['cons_icon_color'] ?? '#ee6a6a'); ?>;
    }
    <?php
    return ob_get_clean();
}
    /**
     * Duplicate a product review group
     *
     * @param int $group_id The ID of the group to duplicate
     * @return int|false The new group ID if successful, false otherwise
     */
    private function duplicate_group($group_id) {
        global $wpdb;
        $group_table = $wpdb->prefix . 'product_review_groups';
        $review_table = $wpdb->prefix . 'product_reviews';

        $group = $wpdb->get_row($wpdb->prepare(
            "SELECT * FROM $group_table WHERE id = %d",
            $group_id
        ), ARRAY_A);

        if (!$group) {
            return false;
        }

        unset($group['id']);
        $group['group_label'] .= ' ' . esc_html__('(Copy)', 'product-review-plugin');
        $group['created_at'] = current_time('mysql');

        $wpdb->insert($group_table, $group);
        $new_group_id = $wpdb->insert_id;

        $reviews = $wpdb->get_results($wpdb->prepare(
            "SELECT * FROM $review_table WHERE group_id = %d",
            $group_id
        ), ARRAY_A);

        foreach ($reviews as $review) {
            unset($review['id']);
            $review['group_id'] = $new_group_id;
            $wpdb->insert($review_table, $review);
        }

        return $new_group_id;
    }

 /**
 * Get license API credentials
 *
 * @return array Credentials array
 */
private static function get_license_credentials() {
    return array(
        'store_url' => 'https://teclans.info/store/',
        'api_endpoint' => 'wp-json/lmfwc/v2/licenses/validate/'
    );
}

/**
 * Validate the license key
 *
 * @param string $license_key The license key to validate
 * @return array Validation result
 */
public static function validate_license($license_key) {
    if (empty($license_key)) {
        return array(
            'is_valid' => false,
            'error' => 'Please enter a license key.'
        );
    }

    $api_url = 'https://teclans.info/store/wp-json/lmfwc/v2/licenses/validate/' . sanitize_text_field($license_key);
    
    $args = array(
        'timeout' => 30,
        'sslverify' => false,
        'headers' => array(
            'Authorization' => 'Basic ' . base64_encode('ck_9296c3506278673c1d65b8c0fd19e20359ab3e61:cs_fb003e42b512120d34128d0b11bf2019d918ef12'),
            'Accept' => 'application/json'
        )
    );

    try {
        $response = wp_remote_get($api_url, $args);

        if (is_wp_error($response)) {
            return array(
                'is_valid' => false,
                'error' => 'Connection error: ' . $response->get_error_message()
            );
        }

        $response_code = wp_remote_retrieve_response_code($response);
        if ($response_code !== 200) {
            return array(
                'is_valid' => false,
                'error' => 'Invalid response code: ' . $response_code
            );
        }

        $body = wp_remote_retrieve_body($response);
        if (empty($body)) {
            return array(
                'is_valid' => false,
                'error' => 'Empty response from license server'
            );
        }

        $data = json_decode($body, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            return array(
                'is_valid' => false,
                'error' => 'Invalid response format'
            );
        }

        if (isset($data['success']) && $data['success'] === true) {
            return array(
                'is_valid' => true,
                'message' => 'License activated successfully!'
            );
        }

        return array(
            'is_valid' => false,
            'error' => isset($data['message']) ? $data['message'] : 'Invalid license key'
        );

    } catch (Exception $e) {
        return array(
            'is_valid' => false,
            'error' => 'Validation error: ' . $e->getMessage()
        );
    }
}

/**
 * Check if the current user is a premium user
 * 
 * @since 1.3
 * @access public
 * @static
 * @return bool Whether the user is premium
 */
public static function is_premium_user() {
    $license_status = get_option( 'product_review_license_status', 'inactive' );
    $license_key    = get_option( 'product_review_license_key', '' );

    if ( 'active' === $license_status && ! empty( $license_key ) ) {
        $last_check = get_transient( 'product_review_license_last_check' );
        if ( false === $last_check ) {
            $validation_result = self::validate_license( $license_key );
            if ( ! $validation_result['is_valid'] ) {
                update_option( 'product_review_license_status', 'inactive' );
                return false;
            }
            set_transient( 'product_review_license_last_check', time(), DAY_IN_SECONDS );
        }
        return true;
    }
    return false;
}

/**
 * Periodic license check
 * 
 * @since 1.3
 * @access public
 * @return void
 */
public function periodic_license_check() {
    $license_key = get_option( 'product_review_license_key', '' );
    if ( ! empty( $license_key ) ) {
        $validation_result = self::validate_license( $license_key );
        if ( ! $validation_result['is_valid'] ) {
            update_option( 'product_review_license_status', 'inactive' );
            delete_transient( 'product_review_license_last_check' );
            
            // Add admin notice for failed validation
            add_settings_error(
                'product_review_license',
                'license_check_failed',
                __( 'License validation failed. Please check your license key.', 'product-review-plugin' ),
                'error'
            );
        }
    }
}
/**
 * Display upgrade notice for free users
 */
public function show_upgrade_notice() {
    // Show notice only on plugin pages and max once per week per user
    $screen = get_current_screen();
    if (!strpos($screen->id, 'product-reviews') === false) {
        return;
    }
    
    $last_notice = get_user_meta(get_current_user_id(), 'product_review_upgrade_notice_last_shown', true);
    if ($last_notice && (time() - $last_notice < WEEK_IN_SECONDS)) {
        return;
    }

    if (!self::is_premium_user()) {
        ?>
        <div class="notice notice-info is-dismissible">
            <p>
                <?php
                echo sprintf(
                    /* translators: %1$s: maximum reviews number */
                    esc_html__('You can add up to %1$s reviews per group in the free version. Need more? Check out our premium features.', 'product-review-plugin'),
                    2
                );
                ?>
                <a href="<?php echo esc_url(admin_url('admin.php?page=product-review-license')); ?>">
                    <?php esc_html_e('Learn More', 'product-review-plugin'); ?>
                </a>
            </p>
        </div>
        <?php
        update_user_meta(get_current_user_id(), 'product_review_upgrade_notice_last_shown', time());
    }
}
   /**
     * Verify required plugin assets exist
     *
     * @since 1.3
     * @access public
     * @static
     * @return void
     */
    public static function verify_plugin_assets() {
        $plugin_dir = plugin_dir_path(__FILE__);
        $required_files = array(
            'assets/icons/check.svg',
            'assets/icons/close.svg'
        );

        $missing_files = array();
        foreach ($required_files as $file) {
            if (!file_exists($plugin_dir . $file)) {
                $missing_files[] = $file;
            }
        }

        if (!empty($missing_files)) {
            $message = 'Product Review Plugin: Missing required files: ' . implode(', ', $missing_files);
            error_log($message);
            if (current_user_can('manage_options')) {
                add_action('admin_notices', function() use ($message) {
                    echo '<div class="error"><p>' . esc_html($message) . '</p></div>';
                });
            }
        }
    }

    /**
     * Plugin activation hook
     */
    public static function activate() {
        global $wpdb;
        $charset_collate = $wpdb->get_charset_collate();

        $group_table = $wpdb->prefix . 'product_review_groups';
        $review_table = $wpdb->prefix . 'product_reviews';

        $sql_group = "CREATE TABLE IF NOT EXISTS $group_table (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            group_label varchar(255) NOT NULL,
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (id)
        ) $charset_collate;";

        $sql_review = "CREATE TABLE IF NOT EXISTS $review_table (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            group_id mediumint(9) NOT NULL,
            product_name varchar(255) NOT NULL,
            product_category varchar(255) NOT NULL,
            product_rating float NOT NULL,
            product_price float NOT NULL,
            product_summary text NOT NULL,
            product_features text NOT NULL,
            product_pros text NOT NULL,
            product_cons text NOT NULL,
            product_who_should_buy text NOT NULL,
            image_url varchar(255),
            description text,
            button_text varchar(255),
            button_url varchar(255),
            PRIMARY KEY (id)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        
        dbDelta($sql_group);
        dbDelta($sql_review);

        // Set default settings
        $default_settings = self::get_default_settings();
        update_option('product_review_settings', $default_settings);
    }

    /**
     * Get default plugin settings
     *
     * @return array Default settings
     */
    public static function get_default_settings() {
        return array(
            // Colors
            'background_color' => '#ffffff',
            'text_color' => '#333333',
            'button_color' => '#3b82f6',
            'button_text_color' => '#ffffff',
            'category_label_bg_color' => '#e0f2fe',
            'category_label_text_color' => '#0369a1',
            'price_color' => '#059669',
            'rating_color' => '#fbbf24',
            'feature_name_bg_color' => '#f0f0f0',
            'feature_value_bg_color' => '#ffffff',
            'star_fill_color' => '#FF9529',
            'star_empty_color' => '#e5e7eb',
            
            // Font Sizes
            'font_size' => 16,
            'button_font_size' => 16,
            'category_label_font_size' => 14,
            'price_font_size' => 24,
            'product_name_font_size' => 24,
            'rating_font_size' => 24,
            'section_title_font_size' => 14,
            'section_content_font_size' => 15,
            
            // Other Settings
            'currency' => 'USD',
            'heading_summary' => __('Summary', 'product-review-plugin'),
            'heading_pros' => __('Pros', 'product-review-plugin'),
            'heading_cons' => __('Cons', 'product-review-plugin'),
            'heading_description' => __('Description', 'product-review-plugin'),
            'heading_who_should_buy' => __('Who Should Buy It?', 'product-review-plugin')
        );
    }
} // End of class ProductReviewPlugin

// Initialize the plugin
function product_review_plugin_init() {
    global $product_review_plugin;
    $product_review_plugin = new ProductReviewPlugin();
}
add_action('init', 'product_review_plugin_init');

// Register activation hook
register_activation_hook(__FILE__, array('ProductReviewPlugin', 'activate'));

// Register deactivation hook
register_deactivation_hook(__FILE__, 'product_review_plugin_deactivate');

/**
 * Plugin deactivation callback
 */
function product_review_plugin_deactivate() {
    wp_clear_scheduled_hook('product_review_daily_event');
}