/**
 * Product Review Plugin Admin Scripts
 * 
 * @package ProductReviewPlugin
 * @since 1.0.0
 */

/* global productReviewL10n, productReviewSettings, wp */
jQuery(function($) {
    'use strict';

    var reviewIndex = 0;

    var ProductReviewAdmin = {
        init: function() {
            // Check if we're on the correct admin page and have necessary globals
            if (!wp || !wp.media) {
                console.error('WordPress Media API not available');
                return;
            }

            this.cacheElements();
            this.initializeExistingReviews();
            this.initializeMediaUploader(this.$reviewFormsContainer);
            this.bindEvents();
            
            // Initialize feature rows for existing forms
            $('.review-form').each(function() {
                if ($(this).find('.features-table tbody tr').length === 0) {
                    ProductReviewAdmin.addFeatureRow($(this).find('.add-feature'));
                }
                ProductReviewAdmin.addFormActionButtons($(this));
            });

            this.cleanupDuplicateButtons();
        },

        cleanupDuplicateButtons: function() {
            // Remove any "Duplicate This Review" buttons
            $('.duplicate-this-review').remove();
            
            // Ensure only one duplicate button per form
            $('.review-form').each(function() {
                var $form = $(this);
                var $duplicateButtons = $form.find('.duplicate-review-form');
                if ($duplicateButtons.length > 1) {
                    $duplicateButtons.not(':first').remove();
                }
            });
        },

        cacheElements: function() {
            this.$reviewFormsContainer = $('#review-forms-container');
            this.$addReviewButton = $('#add-review-form');
            this.$reviewForm = $('#product-review-group-form');
            this.$reviewTemplate = $('#review-form-template');
        },

        initializeExistingReviews: function() {
            var self = this;
            $('.review-form').each(function() {
                var index = parseInt($(this).data('review-index'), 10);
                if (!isNaN(index)) {
                    reviewIndex = Math.max(reviewIndex, index + 1);
                }
            });
            this.checkReviewLimit();
            this.updateReviewNumbers();
        },

        bindEvents: function() {
            this.$addReviewButton.on('click', this.handleAddForm.bind(this));
            $(document).on('click', '.duplicate-review-form', this.handleDuplicateForm.bind(this));
            $(document).on('click', '.remove-review-form', this.handleRemoveForm.bind(this));
            $(document).on('click', '.add-feature', this.handleAddFeature.bind(this));
            $(document).on('click', '.remove-feature', this.handleRemoveFeature.bind(this));
            this.$reviewForm.on('submit', this.handleFormSubmit.bind(this));
        },

        addFormActionButtons: function($form) {
            // Remove existing action buttons if any
            $form.find('.form-actions').remove();

            var $actions = $('<div>', { class: 'form-actions' });

            // Add remove button
            $actions.append($('<button>', {
                type: 'button',
                class: 'button remove-review-form',
                text: productReviewL10n.removeText || 'Remove'
            }));

            // Add duplicate button (only if one doesn't already exist)
            if ($form.find('.duplicate-review-form').length === 0) {
                $actions.append(' ').append($('<button>', {
                    type: 'button',
                    class: 'button duplicate-review-form',
                    text: productReviewL10n.duplicateText || 'Duplicate'
                }));
            }

            $form.append($actions);
            
            // Clean up any duplicate buttons
            this.cleanupDuplicateButtons();
        },

        handleDuplicateForm: function(e) {
    e.preventDefault();
    
    if (this.isReviewLimitReached()) {
        window.alert(productReviewL10n.maxReviewsMessage);
        return;
    }

    var $originalForm = $(e.currentTarget).closest('.review-form');
    var $newForm = $originalForm.clone(true);
    
    // Update form index
    $newForm.attr('data-review-index', reviewIndex);
    
    // Update input names and IDs while preserving values
    $newForm.find('[name], [id]').each(function() {
        var $elem = $(this);
        if ($elem.attr('name')) {
            $elem.attr('name', $elem.attr('name').replace(/\[\d+\]/, '[' + reviewIndex + ']'));
        }
        if ($elem.attr('id')) {
            $elem.attr('id', $elem.attr('id').replace(/_\d+/, '_' + reviewIndex));
        }
    });

    // Selectively clear only specific form elements
    $newForm.find('input[type="file"]').val(''); // Clear file inputs
    $newForm.find('.media-preview').empty(); // Clear preview images if any
    
    // Preserve values for specific fields while copying
    $originalForm.find('input[type="text"], input[type="number"], textarea').each(function() {
        var name = $(this).attr('name');
        var value = $(this).val();
        if (name && value) {
            var newName = name.replace(/\[\d+\]/, '[' + reviewIndex + ']');
            $newForm.find('[name="' + newName + '"]').val(value);
        }
    });

    // Copy feature rows while preserving values
    $newForm.find('.features-table tbody').empty();
    $originalForm.find('.features-table tbody tr').each(function() {
        var $originalRow = $(this);
        var $newRow = $('<tr>');
        
        // Copy feature name
        var $nameCell = $('<td>');
        var $nameInput = $('<input>', {
            type: 'text',
            name: 'feature_name[' + reviewIndex + '][]',
            class: 'regular-text',
            value: $originalRow.find('input[name^="feature_name"]').val()
        });
        $nameCell.append($nameInput);
        
        // Copy feature value
        var $valueCell = $('<td>');
        var $valueInput = $('<input>', {
            type: 'text',
            name: 'feature_value[' + reviewIndex + '][]',
            class: 'regular-text',
            value: $originalRow.find('input[name^="feature_value"]').val()
        });
        $valueCell.append($valueInput);
        
        // Add remove button
        var $actionCell = $('<td>');
        $actionCell.append($('<button>', {
            type: 'button',
            class: 'button remove-feature',
            text: productReviewL10n.removeText || 'Remove'
        }));
        
        $newRow.append($nameCell, $valueCell, $actionCell);
        $newForm.find('.features-table tbody').append($newRow);
    });

    // Append the new form
    $originalForm.after($newForm);
    
    // Initialize media uploader for the new form
    this.initializeMediaUploader($newForm);
    
    // Add action buttons to the new form
    this.addFormActionButtons($newForm);
    
    reviewIndex++;
    this.updateReviewNumbers();
    this.checkReviewLimit();
},

        handleAddFeature: function(e) {
            e.preventDefault();
            this.addFeatureRow($(e.currentTarget));
        },

        addFeatureRow: function($button) {
            var $table = $button.prev('.features-table');
            var formIndex = $button.closest('.review-form').data('review-index');
            var $tbody = $table.find('tbody');
            
            // Create new row
            var $newRow = $('<tr>');
            
            // Feature name cell
            var $nameCell = $('<td>');
            $nameCell.append($('<input>', {
                type: 'text',
                name: 'feature_name[' + formIndex + '][]',
                class: 'regular-text'
            }));
            
            // Feature value cell
            var $valueCell = $('<td>');
            $valueCell.append($('<input>', {
                type: 'text',
                name: 'feature_value[' + formIndex + '][]',
                class: 'regular-text'
            }));
            
            // Action cell
            var $actionCell = $('<td>');
            $actionCell.append($('<button>', {
                type: 'button',
                class: 'button remove-feature',
                text: productReviewL10n.removeText || 'Remove'
            }));
            
            $newRow.append($nameCell, $valueCell, $actionCell);
            $tbody.append($newRow);
        },

        handleRemoveFeature: function(e) {
            e.preventDefault();
            var $row = $(e.currentTarget).closest('tr');
            $row.remove();
            
            // Ensure at least one feature row exists
            var $tbody = $row.closest('tbody');
            if ($tbody.find('tr').length === 0) {
                this.addFeatureRow($tbody.closest('.review-form').find('.add-feature'));
            }
        },

        handleAddForm: function(e) {
            if (e) {
                e.preventDefault();
            }
            
            if (this.isReviewLimitReached()) {
                window.alert(productReviewL10n.maxReviewsMessage);
                return;
            }

            var template = this.$reviewTemplate.html();
            var $newForm = $(template
                .replace(/\{\{index\}\}/g, reviewIndex)
                .replace(/\{\{reviewNumber\}\}/g, $('.review-form').length + 1)
            );

            $newForm.attr('data-review-index', reviewIndex);
            
            this.$reviewFormsContainer.append($newForm);
            this.initializeMediaUploader($newForm);
            this.addFormActionButtons($newForm);
            
            // Add initial feature row
            this.addFeatureRow($newForm.find('.add-feature'));
            
            reviewIndex++;
            this.updateReviewNumbers();
            this.checkReviewLimit();
        },

        handleRemoveForm: function(e) {
            e.preventDefault();
            
            // Check if this is the last form
            if ($('.review-form').length <= 1) {
                window.alert(productReviewL10n.lastFormMessage || 'At least one review form must remain.');
                return;
            }

            var $form = $(e.currentTarget).closest('.review-form');
            
            $form.fadeOut('fast', function() {
                $form.remove();
                ProductReviewAdmin.updateReviewNumbers();
                ProductReviewAdmin.checkReviewLimit();
                
                // Update all forms' action buttons
                $('.review-form').each(function() {
                    ProductReviewAdmin.addFormActionButtons($(this));
                });
            });
        },

        handleFormSubmit: function(e) {
            if ($('.review-form').length > productReviewSettings.maxReviews && 
                !productReviewSettings.isPremiumUser) {
                e.preventDefault();
                window.alert(productReviewL10n.maxReviewsMessage);
            }
        },

        isReviewLimitReached: function() {
            return $('.review-form').length >= productReviewSettings.maxReviews && 
                   !productReviewSettings.isPremiumUser;
        },

        updateReviewNumbers: function() {
            $('.review-form').each(function(index) {
                $(this).find('h3').text(productReviewL10n.reviewNumberText + ' ' + (index + 1));
            });
        },

        checkReviewLimit: function() {
            var isLimitReached = this.isReviewLimitReached();
            this.$addReviewButton.prop('disabled', isLimitReached);
            $('.duplicate-review-form').prop('disabled', isLimitReached);
        },

initializeMediaUploader: function($context) {
    var self = this;
    
    $context.find('.upload-image-button').each(function() {
        var $button = $(this);
        var $container = $button.closest('.image-upload-container');
        var $input = $container.find('input[type="text"]');
        var $previewContainer = $container.find('.media-preview');
        
        // Show existing image preview if URL exists
        if ($input.val()) {
            self.updateImagePreview($previewContainer, $input.val());
        }

        $button.off('click').on('click', function(e) {
            e.preventDefault();
            
            // Create and open media uploader
            var mediaFrame = wp.media({
                title: productReviewL10n.chooseImageText,
                button: {
                    text: productReviewL10n.useThisImageText
                },
                multiple: false,
                library: {
                    type: 'image'
                }
            });

            // Handle image selection
            mediaFrame.on('select', function() {
                var attachment = mediaFrame.state().get('selection').first().toJSON();
                $input.val(attachment.url).trigger('change');
                self.updateImagePreview($previewContainer, attachment.url);
            });

            mediaFrame.open();
        });
    });
},

updateImagePreview: function($container, url) {
            $container.empty();
            
            if (url) {
                var $wrapper = $('<div class="image-preview-wrapper"></div>');
                var $img = $('<img>', {
                    src: url,
                    alt: 'Preview',
                    style: 'max-width: 150px; max-height: 150px;'
                });
                
                var $removeButton = $('<button>', {
                    type: 'button',
                    class: 'button button-small remove-image',
                    text: productReviewL10n.removeImageText
                });

                $wrapper.append($img).append($removeButton);
                $container.append($wrapper);

                // Handle remove button click
                $removeButton.on('click', function(e) {
                    e.preventDefault();
                    var $input = $(this).closest('.image-upload-container').find('.image-url-input');
                    $input.val('').trigger('change');
                    $container.empty();
                });
            }
        }
    }; // Close ProductReviewAdmin object

    // Initialize when document is ready
    $(document).ready(function() {
        ProductReviewAdmin.init();
    });
}); // Close jQuery function