/**
 * Product Review Plugin Frontend Scripts with Local Lazy Loading
 */

(function($) {
    'use strict';

    class LazyLoader {
        constructor() {
            this.images = [];
            this.threshold = 0.01;
            this.observer = null;
            this.observerOptions = {
                root: null,
                rootMargin: '50px 0px',
                threshold: this.threshold
            };
        }

        init() {
            // Check for IntersectionObserver support
            if ('IntersectionObserver' in window) {
                this.observer = new IntersectionObserver(
                    this.onIntersection.bind(this),
                    this.observerOptions
                );
            }
            this.images = document.querySelectorAll('.product-review-plugin img[data-src]');
            this.loadImages();
        }

        loadImages() {
            if (!this.observer) {
                // Fallback for browsers without IntersectionObserver
                this.loadAllImagesImmediately();
                return;
            }

            this.images.forEach(image => {
                if (image.classList.contains('lazy-loaded')) {
                    return;
                }
                this.observer.observe(image);
            });
        }

        onIntersection(entries) {
            entries.forEach(entry => {
                if (entry.intersectionRatio > this.threshold) {
                    this.loadImage(entry.target);
                    this.observer.unobserve(entry.target);
                }
            });
        }

        loadImage(image) {
            const src = image.getAttribute('data-src');
            if (!src) return;

            // Create a new image to preload
            const preloadImage = new Image();
            
            preloadImage.onload = () => {
                image.src = src;
                image.removeAttribute('data-src');
                image.classList.add('lazy-loaded');
                this.fadeInImage(image);
            };

            preloadImage.src = src;
        }

        fadeInImage(image) {
            image.style.opacity = '0';
            image.style.transition = 'opacity 0.3s ease-in';
            
            // Trigger reflow
            image.offsetHeight;
            
            image.style.opacity = '1';
        }

        loadAllImagesImmediately() {
            this.images.forEach(image => {
                this.loadImage(image);
            });
        }

        refresh() {
            this.images = document.querySelectorAll('.product-review-plugin img[data-src]');
            this.loadImages();
        }
    }

    $(document).ready(function() {
        // Initialize lazy loading
        const lazyLoader = new LazyLoader();
        lazyLoader.init();

        // Section toggle functionality
        const $toggleButtons = $('.section-toggle');

        $toggleButtons.on('click', function() {
            const $toggleButton = $(this);
            const $content = $toggleButton.next('.section-content');
            const isExpanded = $toggleButton.attr('aria-expanded') === 'true';

            // Close all sections
            $toggleButtons.attr('aria-expanded', 'false');
            $('.section-content').slideUp(300);

            // Open the clicked section if it was closed
            if (!isExpanded) {
                $toggleButton.attr('aria-expanded', 'true');
                $content.slideDown(300);
            }

            // Refresh lazy loading after content is shown
            setTimeout(() => {
                lazyLoader.refresh();
            }, 350);
        });

        // Ensure keyboard navigation works correctly
        $toggleButtons.on('keydown', function(e) {
            if (e.key === 'Enter' || e.key === ' ') {
                e.preventDefault();
                $(this).click();
            }
        });

        // Expose lazyLoader for potential external use
        window.productReviewLazyLoader = lazyLoader;
    });
})(jQuery);