/**
 * Product Review Plugin Settings JavaScript
 *
 * @package ProductReviewPlugin
 */
(function ($) {
    'use strict';

    /**
     * Initialize color pickers
     */
    const initColorPickers = () => {
        if ($.fn.wpColorPicker) {
            $('.product-review-color-picker').each(function() {
                $(this).wpColorPicker({
                    change: function(event, ui) {
                        $(event.target).val(ui.color.toString()).trigger('change');
                    },
                    clear: function() {
                        const defaultColor = $(this).data('default-color');
                        $(this).wpColorPicker('color', defaultColor);
                    },
                    defaultColor: $(this).data('default-color'),
                    palettes: true
                });
            });
            
            // Change the text of the "Default" button
            $('.wp-picker-default').text(productReviewSettings.resetToDefaultText || 'Reset');
        } else {
            console.error('WordPress Color Picker not available');
        }
    };

    /**
     * Initialize font size reset buttons
     */
    const initFontSizeResetButtons = () => {
        $('input[type="number"]').each(function() {
            const $input = $(this);
            const defaultValue = $input.data('default');
            
            // Remove existing reset button if any
            $input.siblings('.reset-font-size').remove();
            
            // Create reset button with proper spacing
            const $buttonContainer = $('<span>', {
                class: 'reset-button-container',
                style: 'margin-left: 10px; display: inline-block;'
            });

            const $resetButton = $('<button>', {
                type: 'button',
                class: 'button button-secondary reset-font-size',
                text: productReviewSettings.resetToDefaultText || 'Reset',
                style: 'vertical-align: middle;'
            });

            // Click handler
            $resetButton.on('click', function(e) {
                e.preventDefault();
                $input.val(defaultValue);
            });

            // Add button after the "px" text
            $buttonContainer.append($resetButton);
            $input.next('px').after($buttonContainer);
        });
    };

    /**
     * Reset all settings to default values
     */
    const resetAllSettings = () => {
        // Reset colors
        $('.product-review-color-picker').each(function() {
            const defaultColor = $(this).data('default-color');
            $(this).wpColorPicker('color', defaultColor);
        });

        // Reset font sizes
        $('input[type="number"]').each(function() {
            const defaultValue = $(this).data('default');
            $(this).val(defaultValue);
        });

        // Reset currency
        $('select[name="product_review_settings[currency]"]').val('USD');
    };

    /**
     * Add reset functionality for individual color pickers
     */
    const addIndividualColorPickerReset = () => {
        $('.wp-picker-default').on('click', function() {
            const $input = $(this).closest('.wp-picker-container').find('.product-review-color-picker');
            const defaultColor = $input.data('default-color');
            $input.wpColorPicker('color', defaultColor);
        });
    };

    /**
     * Initialize settings page functionality
     */
    const init = () => {
        // Initialize color pickers
        initColorPickers();
        
        // Initialize font size reset buttons
        initFontSizeResetButtons();

        // Add "Reset All" button
        const $resetAllButton = $('<button>', {
            type: 'button',
            class: 'button button-secondary reset-all-settings',
            text: productReviewSettings.resetAllLabel || 'Reset All to Default',
            style: 'margin-top: 20px;'
        });

        $('.product-review-settings-form').append($resetAllButton);
        
        // Reset all handler
        $resetAllButton.on('click', function(e) {
            e.preventDefault();
            if (confirm(productReviewSettings.resetConfirm || 'Are you sure you want to reset all settings to default values?')) {
                resetAllSettings();
            }
        });

        // Add individual color picker reset functionality
        addIndividualColorPickerReset();

        // Handle form submission
        $('.product-review-settings-form').on('submit', function() {
            $('.product-review-color-picker').each(function() {
                $(this).val($(this).wpColorPicker('color'));
            });
        });

        // Handle form reset
        $('.product-review-settings-form').on('reset', function() {
            setTimeout(function() {
                initColorPickers();
                initFontSizeResetButtons();
            }, 0);
        });
    };

    // Initialize when document is ready
    $(document).ready(init);
})(jQuery);